# oneNeuron-pypi
PyPi package for One Neuron Repo

## original project
[Original project link](https://github.com/c17hawke/oneNeuron_pypi)

## how to install
```bash
pip intstall oneNeuron-pypi-sayalasanchit
```

## how to use
```python
from oneNeuron.perceptron import Perceptron
# get X and y (dependent and independent variables)
model=Perceptron(eta, epochs)
model.fit(X, y)
```
